@@ -54,6 +54,10 @@ static int fetch_priority()
 {
 	return cfg_get_single_value_as_int_with_default(config, "lyric-provider", "priority", 90);
 }
+static void set_priority(int priority)
+{
+	cfg_set_single_value_as_int(config, "lyric-provider", "priority", priority);
+}
 
 /**
  * Preferences structure
@@ -68,6 +72,7 @@ gmpcPrefPlugin lyrics_gpp = {
  */
 gmpcMetaDataPlugin lyric_fetch = {
 	.get_priority   = fetch_priority,
+    .set_priority   = set_priority,
 	.get_image      = fetch_lyric
 };
 
@@ -191,7 +196,7 @@ xmlNodePtr get_node_by_name (xmlNodePtr node, xmlChar *name)
 
 static char * __lyrics_process_string(char *name)
 {
-	return escape_uri_string(name);
+	return g_uri_escape_string(name, NULL, TRUE);//g_escape_uri_string(name);
 }
 
 static int fetch_lyrics (mpd_Song *song, struct lyrics_api *api, gchar **lyrics, int exact)
@@ -252,7 +257,7 @@ static int fetch_lyrics (mpd_Song *song, struct lyrics_api *api, gchar **lyrics,
   if (!hid || !strlen(hid))
   {
 	  xmlFreeDoc(results_doc);
-	  xmlCleanupParser();
+	  
 
 	  if (hid)
 		  xmlFree(hid);
@@ -260,7 +265,7 @@ static int fetch_lyrics (mpd_Song *song, struct lyrics_api *api, gchar **lyrics,
 	  return 1;
   }
   xmlFreeDoc(results_doc);
-  xmlCleanupParser();
+  
 
   esc_hid = __lyrics_process_string(hid);
   
@@ -273,7 +278,7 @@ static int fetch_lyrics (mpd_Song *song, struct lyrics_api *api, gchar **lyrics,
   if (!gmpc_easy_download (lyrics_url, &dl))
   {
 	  xmlFree(hid);
-	  xmlCleanupParser();
+	  
 
 	  g_free(lyrics_url);
 	  return 1;
@@ -292,7 +297,7 @@ static int fetch_lyrics (mpd_Song *song, struct lyrics_api *api, gchar **lyrics,
   if(strcasecmp(songtitle, song->title))
   {
 	  xmlFreeDoc(results_doc);
-	  xmlCleanupParser();
+	  
 
 	  xmlFree(hid);
 	  xmlFree(data);
@@ -304,7 +309,7 @@ static int fetch_lyrics (mpd_Song *song, struct lyrics_api *api, gchar **lyrics,
   */ 
   if (!data || !strlen(data))
   {
-	  xmlCleanupParser();
+	  
 	  xmlFree(hid);
 	  xmlFree(data);
 
@@ -316,7 +321,7 @@ static int fetch_lyrics (mpd_Song *song, struct lyrics_api *api, gchar **lyrics,
   /* Cleanup and return */
   xmlFree(data);
   xmlFree(hid);
-  xmlCleanupParser();
+  
 
   return 0;
 }
@@ -405,11 +410,9 @@ static int fetch_lyrics_soap(mpd_Song *song, struct lyrics_api *api, gchar **lyr
   	}
 	
 	init_post_message(&request);
-	char *esc_artist = __lyrics_process_string(song->artist);
-	char *esc_title = __lyrics_process_string(song->title);
-	ret = api->get_soap_message(&request, esc_artist, esc_title);
-	g_free(esc_artist);
-	g_free(esc_title); 
+
+    /* don't escape artist/title here, it isn't needed */
+	ret = api->get_soap_message(&request, song->artist, song->title);
 	
 	if(!ret) {
 		free_post_message(&request); 
@@ -433,14 +436,14 @@ static int fetch_lyrics_soap(mpd_Song *song, struct lyrics_api *api, gchar **lyr
 	free_post_message(&request);
 	
 	if(!xml) {
-		xmlCleanupParser();
+		
 		return 1;
 	}
 	
 	*lyrics = api->get_soap_lyrics(xml, exact); 
 	
 	xmlFreeDoc(xml);
-	xmlCleanupParser();
+	
 	
 	if(*lyrics) 
 		return 0;
@@ -506,7 +509,7 @@ int fetch_lyric(mpd_Song *song, MetaDataType type, char **path)
 		if(!ret  && lyrics && strlen(lyrics))
 		{
 			gchar *filename = g_strdup_printf("%s-%s.lyric", song->artist, song->title);
-			*path = gmpc_get_covers_path(filename); 
+			*path = gmpc_get_metadata_filename(META_SONG_TXT,song,NULL); //gmpc_get_covers_path(filename); 
 			g_file_set_contents(*path, lyrics, -1, NULL);                      				
 			g_free(lyrics);
 			return META_DATA_AVAILABLE;
